==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/sql/kotlin/DatabaseVulnerabilityAssessmentRuleBaselineArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.sql.kotlin

import com.pulumi.azurenative.sql.DatabaseVulnerabilityAssessmentRuleBaselineArgs.builder
import com.pulumi.azurenative.sql.kotlin.inputs.DatabaseVulnerabilityAssessmentRuleBaselineItemArgs
import com.pulumi.azurenative.sql.kotlin.inputs.DatabaseVulnerabilityAssessmentRuleBaselineItemArgsBuilder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * A database vulnerability assessment rule baseline.
 * Azure REST API version: 2021-11-01. Prior API version in Azure Native 1.x: 2020-11-01-preview.
 * Other available API versions: 2022-11-01-preview, 2023-02-01-preview, 2023-05-01-preview.
 * ## Example Usage
 * ### Creates or updates a database's vulnerability assessment rule baseline.
 * ```csharp
 * using System.Collections.Generic;
 * using System.Linq;
 * using Pulumi;
 * using AzureNative = Pulumi.AzureNative;
 * return await Deployment.RunAsync(() =>
 * {
 *     var databaseVulnerabilityAssessmentRuleBaseline = new AzureNative.Sql.DatabaseVulnerabilityAssessmentRuleBaseline("databaseVulnerabilityAssessmentRuleBaseline", new()
 *     {
 *         BaselineName = "default",
 *         BaselineResults = new[]
 *         {
 *             new AzureNative.Sql.Inputs.DatabaseVulnerabilityAssessmentRuleBaselineItemArgs
 *             {
 *                 Result = new[]
 *                 {
 *                     "userA",
 *                     "SELECT",
 *                 },
 *             },
 *             new AzureNative.Sql.Inputs.DatabaseVulnerabilityAssessmentRuleBaselineItemArgs
 *             {
 *                 Result = new[]
 *                 {
 *                     "userB",
 *                     "SELECT",
 *                 },
 *             },
 *             new AzureNative.Sql.Inputs.DatabaseVulnerabilityAssessmentRuleBaselineItemArgs
 *             {
 *                 Result = new[]
 *                 {
 *                     "userC",
 *                     "SELECT",
 *                     "tableId_4",
 *                 },
 *             },
 *         },
 *         DatabaseName = "testdb",
 *         ResourceGroupName = "vulnerabilityaseessmenttest-4799",
 *         RuleId = "VA1001",
 *         ServerName = "vulnerabilityaseessmenttest-6440",
 *         VulnerabilityAssessmentName = "default",
 *     });
 * });
 * ```
 * ```go
 * package main
 * import (
 * 	"github.com/pulumi/pulumi-azure-native-sdk/sql/v2"
 * 	"github.com/pulumi/pulumi/sdk/v3/go/pulumi"
 * )
 * func main() {
 * 	pulumi.Run(func(ctx *pulumi.Context) error {
 * 		_, err := sql.NewDatabaseVulnerabilityAssessmentRuleBaseline(ctx, "databaseVulnerabilityAssessmentRuleBaseline", &sql.DatabaseVulnerabilityAssessmentRuleBaselineArgs{
 * 			BaselineName: pulumi.String("default"),
 * 			BaselineResults: []sql.DatabaseVulnerabilityAssessmentRuleBaselineItemArgs{
 * 				{
 * 					Result: pulumi.StringArray{
 * 						pulumi.String("userA"),
 * 						pulumi.String("SELECT"),
 * 					},
 * 				},
 * 				{
 * 					Result: pulumi.StringArray{
 * 						pulumi.String("userB"),
 * 						pulumi.String("SELECT"),
 * 					},
 * 				},
 * 				{
 * 					Result: pulumi.StringArray{
 * 						pulumi.String("userC"),
 * 						pulumi.String("SELECT"),
 * 						pulumi.String("tableId_4"),
 * 					},
 * 				},
 * 			},
 * 			DatabaseName:                pulumi.String("testdb"),
 * 			ResourceGroupName:           pulumi.String("vulnerabilityaseessmenttest-4799"),
 * 			RuleId:                      pulumi.String("VA1001"),
 * 			ServerName:                  pulumi.String("vulnerabilityaseessmenttest-6440"),
 * 			VulnerabilityAssessmentName: pulumi.String("default"),
 * 		})
 * 		if err != nil {
 * 			return err
 * 		}
 * 		return nil
 * 	})
 * }
 * ```
 * ```java
 * package generated_program;
 * import com.pulumi.Context;
 * import com.pulumi.Pulumi;
 * import com.pulumi.core.Output;
 * import com.pulumi.azurenative.sql.DatabaseVulnerabilityAssessmentRuleBaseline;
 * import com.pulumi.azurenative.sql.DatabaseVulnerabilityAssessmentRuleBaselineArgs;
 * import java.util.List;
 * import java.util.ArrayList;
 * import java.util.Map;
 * import java.io.File;
 * import java.nio.file.Files;
 * import java.nio.file.Paths;
 * public class App {
 *     public static void main(String[] args) {
 *         Pulumi.run(App::stack);
 *     }
 *     public static void stack(Context ctx) {
 *         var databaseVulnerabilityAssessmentRuleBaseline = new DatabaseVulnerabilityAssessmentRuleBaseline("databaseVulnerabilityAssessmentRuleBaseline", DatabaseVulnerabilityAssessmentRuleBaselineArgs.builder()
 *             .baselineName("default")
 *             .baselineResults(
 *                 Map.of("result",
 *                     "userA",
 *                     "SELECT"),
 *                 Map.of("result",
 *                     "userB",
 *                     "SELECT"),
 *                 Map.of("result",
 *                     "userC",
 *                     "SELECT",
 *                     "tableId_4"))
 *             .databaseName("testdb")
 *             .resourceGroupName("vulnerabilityaseessmenttest-4799")
 *             .ruleId("VA1001")
 *             .serverName("vulnerabilityaseessmenttest-6440")
 *             .vulnerabilityAssessmentName("default")
 *             .build());
 *     }
 * }
 * ```
 * ## Import
 * An existing resource can be imported using its type token, name, and identifier, e.g.
 * ```sh
 * $ pulumi import azure-native:sql:DatabaseVulnerabilityAssessmentRuleBaseline default /subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Sql/servers/{serverName}/databases/{databaseName}/vulnerabilityAssessments/{vulnerabilityAssessmentName}/rules/{ruleId}/baselines/{baselineName}
 * ```
 * @property baselineName The name of the vulnerability assessment rule baseline (default implies a baseline on a database level rule and master for server level rule).
 * @property baselineResults The rule baseline result
 * @property databaseName The name of the database for which the vulnerability assessment rule baseline is defined.
 * @property resourceGroupName The name of the resource group that contains the resource. You can obtain this value from the Azure Resource Manager API or the portal.
 * @property ruleId The vulnerability assessment rule ID.
 * @property serverName The name of the server.
 * @property vulnerabilityAssessmentName The name of the vulnerability assessment.
 */
public data class DatabaseVulnerabilityAssessmentRuleBaselineArgs(
    public val baselineName: Output<String>? = null,
    public val baselineResults: Output<List<DatabaseVulnerabilityAssessmentRuleBaselineItemArgs>>? =
        null,
    public val databaseName: Output<String>? = null,
    public val resourceGroupName: Output<String>? = null,
    public val ruleId: Output<String>? = null,
    public val serverName: Output<String>? = null,
    public val vulnerabilityAssessmentName: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.sql.DatabaseVulnerabilityAssessmentRuleBaselineArgs> {
    override fun toJava(): com.pulumi.azurenative.sql.DatabaseVulnerabilityAssessmentRuleBaselineArgs =
        com.pulumi.azurenative.sql.DatabaseVulnerabilityAssessmentRuleBaselineArgs.builder()
            .baselineName(baselineName?.applyValue({ args0 -> args0 }))
            .baselineResults(
                baselineResults?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            )
            .databaseName(databaseName?.applyValue({ args0 -> args0 }))
            .resourceGroupName(resourceGroupName?.applyValue({ args0 -> args0 }))
            .ruleId(ruleId?.applyValue({ args0 -> args0 }))
            .serverName(serverName?.applyValue({ args0 -> args0 }))
            .vulnerabilityAssessmentName(vulnerabilityAssessmentName?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [DatabaseVulnerabilityAssessmentRuleBaselineArgs].
 */
@PulumiTagMarker
public class DatabaseVulnerabilityAssessmentRuleBaselineArgsBuilder internal constructor() {
    private var baselineName: Output<String>? = null

    private var baselineResults: Output<List<DatabaseVulnerabilityAssessmentRuleBaselineItemArgs>>? =
        null

    private var databaseName: Output<String>? = null

    private var resourceGroupName: Output<String>? = null

    private var ruleId: Output<String>? = null

    private var serverName: Output<String>? = null

    private var vulnerabilityAssessmentName: Output<String>? = null

    /**
     * @param value The name of the vulnerability assessment rule baseline (default implies a baseline on a database level rule and master for server level rule).
     */
    @JvmName("vmbwbjovfdqgjffv")
    public suspend fun baselineName(`value`: Output<String>) {
        this.baselineName = value
    }

    /**
     * @param value The rule baseline result
     */
    @JvmName("jcwfybhgmwjbdwum")
    public suspend
    fun baselineResults(`value`: Output<List<DatabaseVulnerabilityAssessmentRuleBaselineItemArgs>>) {
        this.baselineResults = value
    }

    @JvmName("qdfgjnsbiijqmpok")
    public suspend fun baselineResults(
        vararg
        values: Output<DatabaseVulnerabilityAssessmentRuleBaselineItemArgs>,
    ) {
        this.baselineResults = Output.all(values.asList())
    }

    /**
     * @param values The rule baseline result
     */
    @JvmName("qdqvnbriwydsrhoo")
    public suspend
    fun baselineResults(values: List<Output<DatabaseVulnerabilityAssessmentRuleBaselineItemArgs>>) {
        this.baselineResults = Output.all(values)
    }

    /**
     * @param value The name of the database for which the vulnerability assessment rule baseline is defined.
     */
    @JvmName("sprywooidpntdmbc")
    public suspend fun databaseName(`value`: Output<String>) {
        this.databaseName = value
    }

    /**
     * @param value The name of the resource group that contains the resource. You can obtain this value from the Azure Resource Manager API or the portal.
     */
    @JvmName("nctgrfjpqeatypgq")
    public suspend fun resourceGroupName(`value`: Output<String>) {
        this.resourceGroupName = value
    }

    /**
     * @param value The vulnerability assessment rule ID.
     */
    @JvmName("vniomtratxtgkncu")
    public suspend fun ruleId(`value`: Output<String>) {
        this.ruleId = value
    }

    /**
     * @param value The name of the server.
     */
    @JvmName("ebqdkhnanbwftqfv")
    public suspend fun serverName(`value`: Output<String>) {
        this.serverName = value
    }

    /**
     * @param value The name of the vulnerability assessment.
     */
    @JvmName("wepifbjokdgacgxw")
    public suspend fun vulnerabilityAssessmentName(`value`: Output<String>) {
        this.vulnerabilityAssessmentName = value
    }

    /**
     * @param value The name of the vulnerability assessment rule baseline (default implies a baseline on a database level rule and master for server level rule).
     */
    @JvmName("hyrkoaassgserrli")
    public suspend fun baselineName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.baselineName = mapped
    }

    /**
     * @param value The rule baseline result
     */
    @JvmName("japkwbaxwqifimeg")
    public suspend
    fun baselineResults(`value`: List<DatabaseVulnerabilityAssessmentRuleBaselineItemArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.baselineResults = mapped
    }

    /**
     * @param argument The rule baseline result
     */
    @JvmName("qbyoknasxxphtbkn")
    public suspend
    fun baselineResults(argument: List<suspend DatabaseVulnerabilityAssessmentRuleBaselineItemArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            DatabaseVulnerabilityAssessmentRuleBaselineItemArgsBuilder().applySuspend { it() }.build()
        }
        val mapped = of(toBeMapped)
        this.baselineResults = mapped
    }

    /**
     * @param argument The rule baseline result
     */
    @JvmName("fjnpavyecnfsfqut")
    public suspend fun baselineResults(
        vararg
        argument: suspend DatabaseVulnerabilityAssessmentRuleBaselineItemArgsBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map {
            DatabaseVulnerabilityAssessmentRuleBaselineItemArgsBuilder().applySuspend { it() }.build()
        }
        val mapped = of(toBeMapped)
        this.baselineResults = mapped
    }

    /**
     * @param argument The rule baseline result
     */
    @JvmName("tqeklinopjwoupof")
    public suspend
    fun baselineResults(argument: suspend DatabaseVulnerabilityAssessmentRuleBaselineItemArgsBuilder.() -> Unit) {
        val toBeMapped =
            listOf(
                DatabaseVulnerabilityAssessmentRuleBaselineItemArgsBuilder().applySuspend {
                    argument()
                }.build(),
            )
        val mapped = of(toBeMapped)
        this.baselineResults = mapped
    }

    /**
     * @param values The rule baseline result
     */
    @JvmName("lpunwuchlypxtxrv")
    public suspend fun baselineResults(
        vararg
        values: DatabaseVulnerabilityAssessmentRuleBaselineItemArgs,
    ) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.baselineResults = mapped
    }

    /**
     * @param value The name of the database for which the vulnerability assessment rule baseline is defined.
     */
    @JvmName("qhqqaoanadrnolmj")
    public suspend fun databaseName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.databaseName = mapped
    }

    /**
     * @param value The name of the resource group that contains the resource. You can obtain this value from the Azure Resource Manager API or the portal.
     */
    @JvmName("wmeehemieekchmuj")
    public suspend fun resourceGroupName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.resourceGroupName = mapped
    }

    /**
     * @param value The vulnerability assessment rule ID.
     */
    @JvmName("pfatmnbdwprdmfwp")
    public suspend fun ruleId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.ruleId = mapped
    }

    /**
     * @param value The name of the server.
     */
    @JvmName("nxkvyttrnppnkcqx")
    public suspend fun serverName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.serverName = mapped
    }

    /**
     * @param value The name of the vulnerability assessment.
     */
    @JvmName("ikxtmkivvomxyqfp")
    public suspend fun vulnerabilityAssessmentName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.vulnerabilityAssessmentName = mapped
    }

    internal fun build(): DatabaseVulnerabilityAssessmentRuleBaselineArgs =
        DatabaseVulnerabilityAssessmentRuleBaselineArgs(
            baselineName = baselineName,
            baselineResults = baselineResults,
            databaseName = databaseName,
            resourceGroupName = resourceGroupName,
            ruleId = ruleId,
            serverName = serverName,
            vulnerabilityAssessmentName = vulnerabilityAssessmentName,
        )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/sql/kotlin/DatabaseVulnerabilityAssessmentRuleBaselineArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.sql.kotlin

import com.pulumi.azurenative.sql.DatabaseVulnerabilityAssessmentRuleBaselineArgs.builder
import com.pulumi.azurenative.sql.kotlin.inputs.DatabaseVulnerabilityAssessmentRuleBaselineItemArgs
import com.pulumi.azurenative.sql.kotlin.inputs.DatabaseVulnerabilityAssessmentRuleBaselineItemArgsBuilder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * A database vulnerability assessment rule baseline.
 * Azure REST API version: 2021-11-01. Prior API version in Azure Native 1.x: 2020-11-01-preview.
 * Other available API versions: 2022-11-01-preview, 2023-02-01-preview, 2023-05-01-preview.
 * ## Example Usage
 * ### Creates or updates a database's vulnerability assessment rule baseline.
 * ```csharp
 * using System.Collections.Generic;
 * using System.Linq;
 * using Pulumi;
 * using AzureNative = Pulumi.AzureNative;
 * return await Deployment.RunAsync(() =>
 * {
 *     var databaseVulnerabilityAssessmentRuleBaseline = new AzureNative.Sql.DatabaseVulnerabilityAssessmentRuleBaseline("databaseVulnerabilityAssessmentRuleBaseline", new()
 *     {
 *         BaselineName = "default",
 *         BaselineResults = new[]
 *         {
 *             new AzureNative.Sql.Inputs.DatabaseVulnerabilityAssessmentRuleBaselineItemArgs
 *             {
 *                 Result = new[]
 *                 {
 *                     "userA",
 *                     "SELECT",
 *                 },
 *             },
 *             new AzureNative.Sql.Inputs.DatabaseVulnerabilityAssessmentRuleBaselineItemArgs
 *             {
 *                 Result = new[]
 *                 {
 *                     "userB",
 *                     "SELECT",
 *                 },
 *             },
 *             new AzureNative.Sql.Inputs.DatabaseVulnerabilityAssessmentRuleBaselineItemArgs
 *             {
 *                 Result = new[]
 *                 {
 *                     "userC",
 *                     "SELECT",
 *                     "tableId_4",
 *                 },
 *             },
 *         },
 *         DatabaseName = "testdb",
 *         ResourceGroupName = "vulnerabilityaseessmenttest-4799",
 *         RuleId = "VA1001",
 *         ServerName = "vulnerabilityaseessmenttest-6440",
 *         VulnerabilityAssessmentName = "default",
 *     });
 * });
 * ```
 * ```go
 * package main
 * import (
 * 	"github.com/pulumi/pulumi-azure-native-sdk/sql/v2"
 * 	"github.com/pulumi/pulumi/sdk/v3/go/pulumi"
 * )
 * func main() {
 * 	pulumi.Run(func(ctx *pulumi.Context) error {
 * 		_, err := sql.NewDatabaseVulnerabilityAssessmentRuleBaseline(ctx, "databaseVulnerabilityAssessmentRuleBaseline", &sql.DatabaseVulnerabilityAssessmentRuleBaselineArgs{
 * 			BaselineName: pulumi.String("default"),
 * 			BaselineResults: []sql.DatabaseVulnerabilityAssessmentRuleBaselineItemArgs{
 * 				{
 * 					Result: pulumi.StringArray{
 * 						pulumi.String("userA"),
 * 						pulumi.String("SELECT"),
 * 					},
 * 				},
 * 				{
 * 					Result: pulumi.StringArray{
 * 						pulumi.String("userB"),
 * 						pulumi.String("SELECT"),
 * 					},
 * 				},
 * 				{
 * 					Result: pulumi.StringArray{
 * 						pulumi.String("userC"),
 * 						pulumi.String("SELECT"),
 * 						pulumi.String("tableId_4"),
 * 					},
 * 				},
 * 			},
 * 			DatabaseName:                pulumi.String("testdb"),
 * 			ResourceGroupName:           pulumi.String("vulnerabilityaseessmenttest-4799"),
 * 			RuleId:                      pulumi.String("VA1001"),
 * 			ServerName:                  pulumi.String("vulnerabilityaseessmenttest-6440"),
 * 			VulnerabilityAssessmentName: pulumi.String("default"),
 * 		})
 * 		if err != nil {
 * 			return err
 * 		}
 * 		return nil
 * 	})
 * }
 * ```
 * ```java
 * package generated_program;
 * import com.pulumi.Context;
 * import com.pulumi.Pulumi;
 * import com.pulumi.core.Output;
 * import com.pulumi.azurenative.sql.DatabaseVulnerabilityAssessmentRuleBaseline;
 * import com.pulumi.azurenative.sql.DatabaseVulnerabilityAssessmentRuleBaselineArgs;
 * import java.util.List;
 * import java.util.ArrayList;
 * import java.util.Map;
 * import java.io.File;
 * import java.nio.file.Files;
 * import java.nio.file.Paths;
 * public class App {
 *     public static void main(String[] args) {
 *         Pulumi.run(App::stack);
 *     }
 *     public static void stack(Context ctx) {
 *         var databaseVulnerabilityAssessmentRuleBaseline = new DatabaseVulnerabilityAssessmentRuleBaseline("databaseVulnerabilityAssessmentRuleBaseline", DatabaseVulnerabilityAssessmentRuleBaselineArgs.builder()
 *             .baselineName("default")
 *             .baselineResults(
 *                 Map.of("result",
 *                     "userA",
 *                     "SELECT"),
 *                 Map.of("result",
 *                     "userB",
 *                     "SELECT"),
 *                 Map.of("result",
 *                     "userC",
 *                     "SELECT",
 *                     "tableId_4"))
 *             .databaseName("testdb")
 *             .resourceGroupName("vulnerabilityaseessmenttest-4799")
 *             .ruleId("VA1001")
 *             .serverName("vulnerabilityaseessmenttest-6440")
 *             .vulnerabilityAssessmentName("default")
 *             .build());
 *     }
 * }
 * ```
 * ## Import
 * An existing resource can be imported using its type token, name, and identifier, e.g.
 * ```sh
 * $ pulumi import azure-native:sql:DatabaseVulnerabilityAssessmentRuleBaseline default /subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Sql/servers/{serverName}/databases/{databaseName}/vulnerabilityAssessments/{vulnerabilityAssessmentName}/rules/{ruleId}/baselines/{baselineName}
 * ```
 * @property baselineName The name of the vulnerability assessment rule baseline (default implies a baseline on a database level rule and master for server level rule).
 * @property baselineResults The rule baseline result
 * @property databaseName The name of the database for which the vulnerability assessment rule baseline is defined.
 * @property resourceGroupName The name of the resource group that contains the resource. You can obtain this value from the Azure Resource Manager API or the portal.
 * @property ruleId The vulnerability assessment rule ID.
 * @property serverName The name of the server.
 * @property vulnerabilityAssessmentName The name of the vulnerability assessment.
 */
public data class DatabaseVulnerabilityAssessmentRuleBaselineArgs(
    public val baselineName: Output<String>? = null,
    public val baselineResults: Output<List<DatabaseVulnerabilityAssessmentRuleBaselineItemArgs>>? =
        null,
    public val databaseName: Output<String>? = null,
    public val resourceGroupName: Output<String>? = null,
    public val ruleId: Output<String>? = null,
    public val serverName: Output<String>? = null,
    public val vulnerabilityAssessmentName: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.sql.DatabaseVulnerabilityAssessmentRuleBaselineArgs> {
    override fun toJava(): com.pulumi.azurenative.sql.DatabaseVulnerabilityAssessmentRuleBaselineArgs =
        com.pulumi.azurenative.sql.DatabaseVulnerabilityAssessmentRuleBaselineArgs.builder()
            .baselineName(baselineName?.applyValue({ args0 -> args0 }))
            .baselineResults(
                baselineResults?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            )
            .databaseName(databaseName?.applyValue({ args0 -> args0 }))
            .resourceGroupName(resourceGroupName?.applyValue({ args0 -> args0 }))
            .ruleId(ruleId?.applyValue({ args0 -> args0 }))
            .serverName(serverName?.applyValue({ args0 -> args0 }))
            .vulnerabilityAssessmentName(vulnerabilityAssessmentName?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [DatabaseVulnerabilityAssessmentRuleBaselineArgs].
 */
@PulumiTagMarker
public class DatabaseVulnerabilityAssessmentRuleBaselineArgsBuilder internal constructor() {
    private var baselineName: Output<String>? = null

    private var baselineResults: Output<List<DatabaseVulnerabilityAssessmentRuleBaselineItemArgs>>? =
        null

    private var databaseName: Output<String>? = null

    private var resourceGroupName: Output<String>? = null

    private var ruleId: Output<String>? = null

    private var serverName: Output<String>? = null

    private var vulnerabilityAssessmentName: Output<String>? = null

    /**
     * @param value The name of the vulnerability assessment rule baseline (default implies a baseline on a database level rule and master for server level rule).
     */
    @JvmName("cmyltnwbjjmubsfx")
    public suspend fun baselineName(`value`: Output<String>) {
        this.baselineName = value
    }

    /**
     * @param value The rule baseline result
     */
    @JvmName("dycwyfudaxxfgtax")
    public suspend
    fun baselineResults(`value`: Output<List<DatabaseVulnerabilityAssessmentRuleBaselineItemArgs>>) {
        this.baselineResults = value
    }

    @JvmName("wpjuxqctkwvnjteg")
    public suspend fun baselineResults(
        vararg
        values: Output<DatabaseVulnerabilityAssessmentRuleBaselineItemArgs>,
    ) {
        this.baselineResults = Output.all(values.asList())
    }

    /**
     * @param values The rule baseline result
     */
    @JvmName("qypfoakxgibwqgot")
    public suspend
    fun baselineResults(values: List<Output<DatabaseVulnerabilityAssessmentRuleBaselineItemArgs>>) {
        this.baselineResults = Output.all(values)
    }

    /**
     * @param value The name of the database for which the vulnerability assessment rule baseline is defined.
     */
    @JvmName("wabvmrjlaatdcufk")
    public suspend fun databaseName(`value`: Output<String>) {
        this.databaseName = value
    }

    /**
     * @param value The name of the resource group that contains the resource. You can obtain this value from the Azure Resource Manager API or the portal.
     */
    @JvmName("ukecsnvhefyxvamy")
    public suspend fun resourceGroupName(`value`: Output<String>) {
        this.resourceGroupName = value
    }

    /**
     * @param value The vulnerability assessment rule ID.
     */
    @JvmName("uhecdvnvqmswtfvn")
    public suspend fun ruleId(`value`: Output<String>) {
        this.ruleId = value
    }

    /**
     * @param value The name of the server.
     */
    @JvmName("ipidkqdthgshtlsw")
    public suspend fun serverName(`value`: Output<String>) {
        this.serverName = value
    }

    /**
     * @param value The name of the vulnerability assessment.
     */
    @JvmName("fjgehgrjyulbbcjb")
    public suspend fun vulnerabilityAssessmentName(`value`: Output<String>) {
        this.vulnerabilityAssessmentName = value
    }

    /**
     * @param value The name of the vulnerability assessment rule baseline (default implies a baseline on a database level rule and master for server level rule).
     */
    @JvmName("kgyiyjjdmdbltgne")
    public suspend fun baselineName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.baselineName = mapped
    }

    /**
     * @param value The rule baseline result
     */
    @JvmName("koshapygtnvqhxgy")
    public suspend
    fun baselineResults(`value`: List<DatabaseVulnerabilityAssessmentRuleBaselineItemArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.baselineResults = mapped
    }

    /**
     * @param argument The rule baseline result
     */
    @JvmName("idgdxegkfmagppty")
    public suspend
    fun baselineResults(argument: List<suspend DatabaseVulnerabilityAssessmentRuleBaselineItemArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            DatabaseVulnerabilityAssessmentRuleBaselineItemArgsBuilder().applySuspend { it() }.build()
        }
        val mapped = of(toBeMapped)
        this.baselineResults = mapped
    }

    /**
     * @param argument The rule baseline result
     */
    @JvmName("itgctjnailcxrrrc")
    public suspend fun baselineResults(
        vararg
        argument: suspend DatabaseVulnerabilityAssessmentRuleBaselineItemArgsBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map {
            DatabaseVulnerabilityAssessmentRuleBaselineItemArgsBuilder().applySuspend { it() }.build()
        }
        val mapped = of(toBeMapped)
        this.baselineResults = mapped
    }

    /**
     * @param argument The rule baseline result
     */
    @JvmName("paumlijrhtttebmy")
    public suspend
    fun baselineResults(argument: suspend DatabaseVulnerabilityAssessmentRuleBaselineItemArgsBuilder.() -> Unit) {
        val toBeMapped =
            listOf(
                DatabaseVulnerabilityAssessmentRuleBaselineItemArgsBuilder().applySuspend {
                    argument()
                }.build(),
            )
        val mapped = of(toBeMapped)
        this.baselineResults = mapped
    }

    /**
     * @param values The rule baseline result
     */
    @JvmName("joqomvncqkitxdrr")
    public suspend fun baselineResults(
        vararg
        values: DatabaseVulnerabilityAssessmentRuleBaselineItemArgs,
    ) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.baselineResults = mapped
    }

    /**
     * @param value The name of the database for which the vulnerability assessment rule baseline is defined.
     */
    @JvmName("trcemdaipgnsslvs")
    public suspend fun databaseName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.databaseName = mapped
    }

    /**
     * @param value The name of the resource group that contains the resource. You can obtain this value from the Azure Resource Manager API or the portal.
     */
    @JvmName("isppeblrnhbfyjqe")
    public suspend fun resourceGroupName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.resourceGroupName = mapped
    }

    /**
     * @param value The vulnerability assessment rule ID.
     */
    @JvmName("vrencrelvvnbstbf")
    public suspend fun ruleId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.ruleId = mapped
    }

    /**
     * @param value The name of the server.
     */
    @JvmName("brppdwjwpsrrohbv")
    public suspend fun serverName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.serverName = mapped
    }

    /**
     * @param value The name of the vulnerability assessment.
     */
    @JvmName("wivajbtnnjcihteu")
    public suspend fun vulnerabilityAssessmentName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.vulnerabilityAssessmentName = mapped
    }

    internal fun build(): DatabaseVulnerabilityAssessmentRuleBaselineArgs =
        DatabaseVulnerabilityAssessmentRuleBaselineArgs(
            baselineName = baselineName,
            baselineResults = baselineResults,
            databaseName = databaseName,
            resourceGroupName = resourceGroupName,
            ruleId = ruleId,
            serverName = serverName,
            vulnerabilityAssessmentName = vulnerabilityAssessmentName,
        )
}
